@@ -136,7 +136,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "ja");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Shiretoko/3.5");
+pref("general.useragent.extra.firefox", "Shiretoko/3.5.1");
 
 pref("general.smoothScroll", false);
 //@line 183 "/home/karma/src/build/build/browser/app/profile/firefox.js"
